# pythonUtils
Some personal librarys for python

Install instructions:

```
pip install erlenberg
```

Usage instructions in python program:

```
import erlenberg
logger = erlenberg.logHandler.Logger(erlenberg.logHandler.DEBUG).start()

logger.debug('Some debug message')
```

Usage instructions for the specific submodules (e.g. logHandler) can be found in the "information" directory.
